.. image:: ../../imgs/ooipy_banner2.png
  :width: 700
  :alt: OOIPY Logo
  :align: left

Tools Module
============
This module provides some additional tools for visualizing and saving
spectrogram and power spectral density objects

Visualization
^^^^^^^^^^^^^
.. automodule:: ooipy.tools.ooiplotlib
    :members:

Workflow
^^^^^^^^
.. automodule:: ooipy.tools.workflow
    :members: